/*
 * The Initial Developer of the Original Code is Lutris Technologies Inc.
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc.
 * All Rights Reserved.
 *-----------------------------------------------------------------------------
 * $Id: TransactionManager.java,v 1.2 2003/01/07 14:32:01 jmesnil Exp $
 *-----------------------------------------------------------------------------
 */
package org.objectweb.transaction.jta;

import java.util.List;

/**
 * A <code>TransactionManager</code> extends JTA
 * <code>javax.transaction.TransactionManager</code> with an event API that
 * allows late enlistment of connections opened by resource managers before the
 * transaction has begun. <br />
 * 
 * To enable late enlistment of connections, the <code>TransactionManager</code>
 * must be registered as a <code>ResourceManagerEventListener</code> with the
 * resource manager.<br/> 
 * When the transaction manager receives an event from a
 * resource manager, it stores the events in a thread local list. The thread
 * local lists can be stacked/unstacked with the two methods
 * <code>pushThreadLocalRMEventList</code> and
 * <code>popThreadLocalRMEventList</code>. This is typically used when different
 * event lists are to be nested in the same thread, or when a list spams several
 * threads.
 * 
 *  Created on Feb 7, 2002
 *  @author   Christophe Ney, cney@batisseurs. com
 */
public interface TransactionManager extends javax.transaction.TransactionManager, ResourceManagerEventListener {

    /**
     * Push a new event list on the stack of thread local resource event sets.
     * The list must contain only <code>ResourceManagerEvent</code> objects.
     * 
     * @param eventList the possibly null list of events to store forecoming
     * <code>ResourceManagerEvent</code> events occuring in the current thread.
     */
    public void pushThreadLocalRMEventList(List eventList);

    /**
     * Pop the current set from the stack of thread local resource event sets
     * The list contains <code>ResourceManagerEvent</code> objects.
     * 
     * @return The possibly null <code>ResourceManagerEvent</code> list of events
     * that have occured in the  current thread since the last call of
     * <code>pushThreadLocalRMEventList</code> or since the thread started.
     */
    public List popThreadLocalRMEventList();
}